@@ -24,7 +24,6 @@
 #include "mul.h"
 #include "archive.h"
 #include "operators.h"
-#include "matrix.h"
 #include "utils.h"
 #include "clifford.h"
 #include "ncmul.h"
@@ -233,7 +232,7 @@ void add::do_print_csrc(const print_csrc & c, unsigned level) const
 		c.s << ")";
 }
 
-void add::do_print_python_repr(const print_python_repr & c, unsigned) const
+void add::do_print_python_repr(const print_python_repr & c, unsigned /*level*/) const
 {
 	c.s << class_name() << '(';
 	op(0).print(c);
@@ -363,7 +362,7 @@ ex add::coeff(const ex & s, int n) const
 ex add::eval(int level) const
 {
 	std::unique_ptr<epvector> evaled_seqp = evalchildren(level);
-	if (unlikely(evaled_seqp.get() != nullptr)) {
+	if (unlikely(evaled_seqp != nullptr)) {
 		// do more evaluation later
 		return (new add(*evaled_seqp, overall_coeff))->
 		       setflag(status_flags::dynallocated);
@@ -378,7 +377,7 @@ ex add::eval(int level) const
 	}
 #endif // def DO_GINAC_ASSERT
 	
-	if (flags & status_flags::evaluated) {
+	if ((flags & status_flags::evaluated) != 0u) {
 		GINAC_ASSERT(seq.size()>0);
 		GINAC_ASSERT(seq.size()>1 || !overall_coeff.is_zero());
 		return *this;
@@ -407,7 +406,7 @@ ex add::eval(int level) const
 	for (const auto & elem : seq)
 		if (unlikely(is_exactly_a<numeric>(elem.rest)))
 			++terms_to_collect;
-	if (terms_to_collect) {
+	if (terms_to_collect != 0) {
                 epvector s;
 		s.reserve(seq_size - terms_to_collect);
 		numeric oc = *_num0_p;
@@ -452,36 +451,6 @@ ex add::eval_infinity(epvector::const_iterator infinity_iter) const
 }
 
 
-ex add::evalm() const
-{
-	// Evaluate children first and add up all matrices. Stop if there's one
-	// term that is not a matrix.
-	epvector s;
-	s.reserve(seq.size());
-
-	bool all_matrices = true;
-	bool first_term = true;
-	matrix sum;
-
-	for (const auto & elem : seq) {
-		const ex &m = recombine_pair_to_ex(elem).evalm();
-		s.push_back(split_ex_to_pair(m));
-		if (is_exactly_a<matrix>(m)) {
-			if (first_term) {
-				sum = ex_to<matrix>(m);
-				first_term = false;
-			} else
-				sum = sum.add(ex_to<matrix>(m));
-		} else
-			all_matrices = false;
-	}
-
-	if (all_matrices)
-		return sum + overall_coeff;
-	else
-		return (new add(s, overall_coeff))->setflag(status_flags::dynallocated);
-}
-
 ex add::conjugate() const
 {
 	std::unique_ptr<exvector> v(nullptr);
@@ -590,13 +559,13 @@ tinfo_t add::return_type_tinfo() const
 }
 
 // Note: do_index_renaming is ignored because it makes no sense for an add.
-ex add::thisexpairseq(const epvector & v, const ex & oc, bool) const
+ex add::thisexpairseq(const epvector & v, const ex & oc, bool /*do_index_renaming*/) const
 {
 	return (new add(v,oc))->setflag(status_flags::dynallocated);
 }
 
 //// Note: do_index_renaming is ignored because it makes no sense for an add.
-ex add::thisexpairseq(std::unique_ptr<epvector> vp, const ex & oc, bool) const
+ex add::thisexpairseq(std::unique_ptr<epvector> vp, const ex & oc, bool /*do_index_renaming*/) const
 {
 	return (new add(*vp,oc))->setflag(status_flags::dynallocated);
 }
@@ -671,7 +640,7 @@ ex add::recombine_pair_to_ex(const expair & p) const
 ex add::expand(unsigned options) const
 {
 	std::unique_ptr<epvector> vp = expandchildren(options);
-	if (vp.get() == nullptr) {
+	if (vp == nullptr) {
 		// the terms have not changed, so it is safe to declare this expanded
 		return (options == 0) ? setflag(status_flags::expanded) : *this;
 	}
