@@ -26,9 +26,10 @@
 #include "mul.h"
 #include "ncmul.h"
 #include "numeric.h"
-#include "matrix.h"
 #include "power.h"
 #include "lst.h"
+#include "function.h"
+#include "symbol.h"
 #include "relational.h"
 #include "utils.h"
 
@@ -73,7 +74,7 @@ void ex::dbgprinttree() const
 
 ex ex::expand(unsigned options) const
 {
-	if (options == 0 && (bp->flags & status_flags::expanded)) // The "expanded" flag only covers the standard options; someone might want to re-expand with different options
+	if (options == 0 && ((bp->flags & status_flags::expanded) != 0u)) // The "expanded" flag only covers the standard options; someone might want to re-expand with different options
 		return *this;
 	else
 		return bp->expand(options);
@@ -86,7 +87,7 @@ ex ex::expand(unsigned options) const
  *  @return partial derivative as a new expression */
 ex ex::diff(const symbol & s, unsigned nth) const
 {
-	if (!nth)
+	if (nth == 0u)
 		return *this;
 	else
 		return bp->diff(s, nth);
@@ -126,7 +127,7 @@ ex ex::subs(const lst & ls, const lst & lr, unsigned options) const
 
 	// Convert the lists to a map
 	exmap m;
-	for (lst::const_iterator its = ls.begin(), itr = lr.begin(); its != ls.end(); ++its, ++itr) {
+	for (auto its = ls.begin(), itr = lr.begin(); its != ls.end(); ++its, ++itr) {
 		m.insert(std::make_pair(*its, *itr));
 
 		// Search for products and powers in the expressions to be substituted
@@ -134,7 +135,7 @@ ex ex::subs(const lst & ls, const lst & lr, unsigned options) const
 		if (is_exactly_a<mul>(*its) || is_exactly_a<power>(*its))
 			options |= subs_options::pattern_is_product;
 	}
-	if (!(options & subs_options::pattern_is_product))
+	if ((options & subs_options::pattern_is_product) == 0u)
 		options |= subs_options::pattern_is_not_product;
 
 	return bp->subs(m, options);
@@ -165,8 +166,8 @@ ex ex::subs(const ex & e, unsigned options) const
 		// Argument is a list: convert it to a map
 		exmap m;
 		GINAC_ASSERT(is_a<lst>(e));
-		for (lst::const_iterator it = ex_to<lst>(e).begin(); it != ex_to<lst>(e).end(); ++it) {
-			ex r = *it;
+		for (auto r : ex_to<lst>(e)) {
+			
 			if (!r.info(info_flags::relation_equal))
 				throw(std::invalid_argument("basic::subs(ex): argument must be a list of equations"));
 			const ex & s = r.op(0);
@@ -177,7 +178,7 @@ ex ex::subs(const ex & e, unsigned options) const
 			if (is_exactly_a<mul>(s) || is_exactly_a<power>(s))
 				options |= subs_options::pattern_is_product;
 		}
-		if (!(options & subs_options::pattern_is_product))
+		if ((options & subs_options::pattern_is_product) == 0u)
 			options |= subs_options::pattern_is_not_product;
 
 		return bp->subs(m, options);
@@ -225,6 +226,54 @@ ex & ex::operator[](size_t i)
 	return (*bp)[i];
 }
 
+bool ex::is_equal(const ex & other) const
+{
+#ifdef GINAC_COMPARE_STATISTICS
+	compare_statistics.total_is_equals++;
+#endif
+	if (bp == other.bp)  // trivial case: both expressions point to same basic
+		return true;
+#ifdef GINAC_COMPARE_STATISTICS
+	compare_statistics.nontrivial_is_equals++;
+#endif
+	if (is_exactly_a<numeric>(*this) and is_exactly_a<numeric>(other))
+		return ex_to<numeric>(*this).is_equal(ex_to<numeric>(other));
+	const bool equal = bp->is_equal(*other.bp);
+#if 0
+	if (equal) {
+		// Expressions point to different, but equal, trees: conserve
+		// memory and make subsequent compare() operations faster by
+		// making both expressions point to the same tree.
+		share(other);
+	}
+#endif
+	return equal;
+}
+
+int ex::compare(const ex & other) const
+{
+#ifdef GINAC_COMPARE_STATISTICS
+	compare_statistics.total_compares++;
+#endif
+	if (bp == other.bp)  // trivial case: both expressions point to same basic
+		return 0;
+#ifdef GINAC_COMPARE_STATISTICS
+	compare_statistics.nontrivial_compares++;
+#endif
+	if (is_exactly_a<numeric>(*this) and is_exactly_a<numeric>(other))
+		return ex_to<numeric>(*this).compare_same_type(ex_to<numeric>(other));
+	const int cmpval = bp->compare(*other.bp);
+#if 1
+	if (cmpval == 0) {
+		// Expressions point to different, but equal, trees: conserve
+		// memory and make subsequent compare() operations faster by
+		// making both expressions point to the same tree.
+		share(other);
+	}
+#endif
+	return cmpval;
+}
+
 /** Left hand side of relational expression. */
 ex ex::lhs() const
 {
@@ -246,8 +295,8 @@ bool ex::is_polynomial(const ex & vars) const
 {
 	if (is_exactly_a<lst>(vars)) {
 		const lst & varlst = ex_to<lst>(vars);
-		for (lst::const_iterator i=varlst.begin(); i!=varlst.end(); ++i)
-			if (!bp->is_polynomial(*i))
+		for (const auto & elem : varlst)
+			if (!bp->is_polynomial(elem))
 				return false;
 		return true;
 	}
@@ -264,17 +313,6 @@ bool ex::is_zero() const {
         return ex_to<numeric>(*this).is_zero();
 }
 
-/** Check whether expression is zero or zero matrix. */
-bool ex::is_zero_matrix() const
-{
-	if (is_zero())
-		return  true;
-	else {
-		ex e = evalm();
-		return is_exactly_a<matrix>(e) && ex_to<matrix>(e).is_zero_matrix();
-	}
-}
-
 bool ex::is_integer_one() const
 {
     if (!is_exactly_a<numeric>(*this))
@@ -293,6 +331,18 @@ bool ex::is_integer_pmone() const
             or ex_to<numeric>(*this).is_equal(*_num_1_p)));
 }
 
+void ex::set_domain(unsigned d)
+{
+        if (is_exactly_a<symbol>(*this)) {
+                symbol &s = dynamic_cast<symbol&>(*bp);
+                s.set_domain(d);
+        }
+        else if (is_exactly_a<function>(*this)) {
+                function &f = dynamic_cast<function&>(*bp);
+                f.set_domain(d);
+        }
+}
+
 size_t ex::nsymbols() const
 {
 	int res = 0;
@@ -305,6 +355,45 @@ size_t ex::nsymbols() const
 	return res;
 }
 
+/** Return pointer to first symbol found in expression.  Due to GiNaC's
+ *  internal ordering of terms, it may not be obvious which symbol this
+ *  function returns for a given expression.
+ *
+ *  @param e  expression to search
+ *  @param x  first symbol found (returned)
+ *  @return "false" if no symbol was found, "true" otherwise */
+bool ex::get_first_symbol(ex &x) const
+{
+	if (is_exactly_a<symbol>(*this)) {
+		x = *this;
+		return true;
+	} else if (is_exactly_a<add>(*this) || is_exactly_a<mul>(*this)) {
+		for (size_t i=0; i<nops(); i++)
+			if (sorted_op(i).get_first_symbol(x))
+				return true;
+	} else if (is_exactly_a<power>(*this)) {
+		if (op(0).get_first_symbol(x))
+			return true;
+	}
+	return false;
+}
+
+static void collect_symbols(const ex& e, symbolset& syms)
+{
+	if (is_exactly_a<symbol>(e))
+		syms.insert(ex_to<symbol>(e));
+	else
+		for (size_t i=0; i < e.nops(); i++)
+                        collect_symbols(e.op(i), syms);
+}
+
+symbolset ex::symbols() const
+{
+        symbolset the_set;
+        collect_symbols(*this, the_set);
+	return the_set;
+}
+
 ex ex::sorted_op(size_t i) const
 {
 	if (is_a<expairseq>(*this))
@@ -327,7 +416,7 @@ void ex::makewriteable()
  *  @see ex::compare(const ex &) */
 void ex::share(const ex & other) const
 {
-	if ((bp->flags | other.bp->flags) & status_flags::not_shareable)
+	if (((bp->flags | other.bp->flags) & status_flags::not_shareable) != 0u)
 		return;
 
 	if (bp->get_refcount() <= other.bp->get_refcount())
@@ -341,7 +430,7 @@ void ex::share(const ex & other) const
  *  @see ex::ex(const basic &) */
 ptr<basic> ex::construct_from_basic(const basic & other)
 {
-	if (!(other.flags & status_flags::evaluated)) {
+	if ((other.flags & status_flags::evaluated) == 0u) {
 
 		// The object is not yet evaluated, so call eval() to evaluate
 		// the top level. This will return either
@@ -368,7 +457,7 @@ ptr<basic> ex::construct_from_basic(const basic & other)
 		// it means that eval() hit case b) above. The original object is
 		// no longer needed (it evaluated into something different), so we
 		// delete it (because nobody else will).
-		if ((other.get_refcount() == 0) && (other.flags & status_flags::dynallocated))
+		if ((other.get_refcount() == 0) && ((other.flags & status_flags::dynallocated) != 0u))
 			delete &other; // yes, you can apply delete to a const pointer
 
 		// We can't return a basic& here because the tmpex is destroyed as
@@ -379,7 +468,7 @@ ptr<basic> ex::construct_from_basic(const basic & other)
 	} else {
 
 		// The easy case: making an "ex" out of an evaluated object.
-		if (other.flags & status_flags::dynallocated) {
+		if ((other.flags & status_flags::dynallocated) != 0u) {
 
 			// The object is already heap-allocated, so we can just make
 			// another reference to it.
