@@ -23,7 +23,6 @@
 #include "mul.h"
 #include "add.h"
 #include "operators.h"
-#include "matrix.h"
 #include "indexed.h"
 #include "lst.h"
 #include "archive.h"
@@ -364,7 +363,7 @@ void mul::do_print_rat_func(const print_context & c, unsigned level,
 			print_latex tcontext(tstream, c.options);
 			print_exvector(others, tcontext, sep);
 			print_overall_coeff(overall_coeff, c,
-					std::isdigit(tstream.peek()) ?
+					std::isdigit(tstream.peek()) != 0 ?
 						" \\cdot " : " \\, ",
 					latex_tags);
 			c.s<<tstream.str();
@@ -641,7 +640,7 @@ ex mul::coeff(const ex & s, int n) const
 ex mul::eval(int level) const
 {
 	std::unique_ptr<epvector> evaled_seqp = evalchildren(level);
-	if (unlikely(evaled_seqp.get() != nullptr)) {
+	if (unlikely(evaled_seqp != nullptr)) {
 		// do more evaluation later
 		return (new mul(*evaled_seqp, overall_coeff))->
 		           setflag(status_flags::dynallocated);
@@ -665,7 +664,7 @@ ex mul::eval(int level) const
 	}
 #endif // def DO_GINAC_ASSERT
 	
-	if (flags & status_flags::evaluated) {
+	if ((flags & status_flags::evaluated) != 0u) {
 		GINAC_ASSERT(seq.size()>0);
 		GINAC_ASSERT(seq.size()>1 || !overall_coeff.is_integer_one());
 		return *this;
@@ -718,7 +717,7 @@ ex mul::eval(int level) const
                         return result.overall_coeff;
                 else
                         return x;
-	} else if ((seq_size >= 2) && (! (flags & status_flags::expanded))) {
+	} else if ((seq_size >= 2) && ((flags & status_flags::expanded) == 0u)) {
 		// Strip the content and the unit part from each term. Thus
 		// things like (-x+a)*(3*x-3*a) automagically turn into - 3*(x-a)2
 
@@ -904,44 +903,6 @@ ex mul::imag_part() const
 	return ip;
 }
 
-ex mul::evalm() const
-{
-	// numeric*matrix
-	if (seq.size() == 1 && seq[0].coeff.is_equal(_ex1)
-	 && is_exactly_a<matrix>(seq[0].rest))
-		return ex_to<matrix>(seq[0].rest).mul(ex_to<numeric>(overall_coeff));
-
-	// Evaluate children first, look whether there are any matrices at all
-	// (there can be either no matrices or one matrix; if there were more
-	// than one matrix, it would be a non-commutative product)
-	epvector s;
-	s.reserve(seq.size());
-
-	bool have_matrix = false;
-	epvector::iterator the_matrix;
-
-        for (const auto & elem : seq) {
-		const ex &m = recombine_pair_to_ex(elem).evalm();
-		s.push_back(split_ex_to_pair(m));
-		if (is_exactly_a<matrix>(m)) {
-			have_matrix = true;
-			the_matrix = s.end() - 1;
-		}
-	}
-
-	if (have_matrix) {
-
-		// The product contained a matrix. We will multiply all other factors
-		// into that matrix.
-		matrix m = ex_to<matrix>(the_matrix->rest);
-		s.erase(the_matrix);
-		ex scalar = (new mul(s, overall_coeff))->setflag(status_flags::dynallocated);
-		return m.mul_scalar(scalar);
-
-	} else
-		return (new mul(s, overall_coeff))->setflag(status_flags::dynallocated);
-}
-
 ex mul::eval_ncmul(const exvector & v) const
 {
 	if (seq.empty())
@@ -1039,7 +1000,7 @@ bool algebraic_match_mul_with_mul(const mul &e, const ex &pat, lst &repls,
 
 bool mul::has(const ex & pattern, unsigned options) const
 {
-	if(!(options&has_options::algebraic))
+	if((options&has_options::algebraic) == 0u)
 		return basic::has(pattern,options);
 	if(is_exactly_a<mul>(pattern)) {
 		lst repls;
@@ -1172,7 +1133,7 @@ ex mul::derivative(const symbol & s) const
  Beware that symbolic exponents are wrapped inside pow objects with 1 as coeff. */
 double mul::total_degree() const
 {
-	if (flags & status_flags::tdegree_calculated) {
+	if ((flags & status_flags::tdegree_calculated) != 0u) {
 		return tdegree;
 	}
 	numeric tdeg = calc_total_degree();
@@ -1374,15 +1335,15 @@ ex mul::expand(unsigned options) const
         }
 
 	// do not rename indices if the object has no indices at all
-	if ((!(options & expand_options::expand_rename_idx)) && 
+	if (((options & expand_options::expand_rename_idx) == 0u) && 
 			this->info(info_flags::has_indices))
 		options |= expand_options::expand_rename_idx;
 
-	const bool skip_idx_rename = !(options & expand_options::expand_rename_idx);
+	const bool skip_idx_rename = (options & expand_options::expand_rename_idx) == 0u;
 
 	// First, expand the children
 	std::unique_ptr<epvector> expanded_seqp = expandchildren(options);
-	const epvector & expanded_seq = (expanded_seqp.get() ? *expanded_seqp : seq);
+	const epvector & expanded_seq = (expanded_seqp.get() != nullptr ? *expanded_seqp : seq);
 
 	// Now, look for all the factors that are sums and multiply each one out
 	// with the next one that is found while collecting the factors which are
